#include <QtNetwork>
#include "downloader.h"

Downloader::Downloader()
{
    isImage = false;
}

void Downloader::startRequest(QUrl url, QObject* receiver) //Gets requesthandlerclass object as second parameter, this is because of signal->slot connection
{

    request.setUrl(QUrl(url));
    request.setRawHeader( "User-Agent", "Mozilla/5.0 (X11; U; Linux i686 (x86_64); " "en-US; rv:1.9.0.1) Gecko/2008070206 Firefox/3.0.1" );
    // user-agent set to Firefox because otherwise the downloaded xml-files aren't suitable
    reply = qnam.get(request);
    connect(reply, SIGNAL(finished()),
            this, SLOT(httpFinished()));
    connect(this, SIGNAL(downloaderReady()),
            receiver, SLOT(setComplete()));
}

void Downloader::downloadFile(QString urlToFetch, QObject* receiver) //Overwrites if file to be downloaded already exists
{
    QUrl url(urlToFetch);

    QFileInfo fileInfo(url.path());
    QString fileName;
    if(urlToFetch.contains("item-tooltip.xml"))
        fileName = "cache/" + urlToFetch.mid(urlToFetch.lastIndexOf("?") + 3) + fileInfo.fileName(); //Used to separate item XML files using item ID
    else
        fileName = "cache/" + fileInfo.fileName();

    if (QFile::exists(fileName))
        QFile::remove(fileName);

    file = new QFile(fileName);
    if (!file->open(QIODevice::WriteOnly)) {
        delete file;
        file = 0;
        return;
    }

    startRequest(url, receiver);
}

void Downloader::httpFinished() //Function to execute on finished download. Contains basic error handling
{
    file->write(reply->readAll());
    file->flush();
    file->close();

    QVariant redirectionTarget = reply->attribute(QNetworkRequest::RedirectionTargetAttribute);
    if (reply->error())
        file->remove();
    else if (!redirectionTarget.isNull()) {
        QUrl newUrl = url.resolved(redirectionTarget.toUrl());
            url = newUrl;
            reply->deleteLater();
            file->open(QIODevice::WriteOnly);
            file->resize(0);
    }

    reply->deleteLater();
    reply = 0;
    emit downloaderReady(); //Signal to downloadmanager

}

void Downloader::setComplete() {
}
