#include "requesthandlerclass.h"
#include "downloader.h"
#include <QMap>
#include <QString>
#include <QVector>
#include "window.h"
#include "vectorhandler.h"

RequestHandlerClass::RequestHandlerClass()
{
    connect(this, SIGNAL(allComplete()),
            this, SLOT(completed()));
}

//class creates and manages instances of downloaders
//management is done using QMap
//parameters: number of downloaders and "id" of caller function, so application execution phase is known
void RequestHandlerClass::setInstances(int reqNum, int caller) {
    this->caller = caller;
    numberOfDownloaders = reqNum;
    for(int i = 0; i < reqNum; i++) {
        Downloader* downloader = new Downloader;
        downloaderMap.insert(i, downloader);
    }
}

void RequestHandlerClass::download(int index, QString url) {

    Downloader * instance = downloaderMap.value(index);
    (*instance).downloadFile(url, this);
}

//Emits signal when all downloads have finished
void RequestHandlerClass::setComplete() {
    numberOfDownloaders--;
    if(numberOfDownloaders == 0) {
        emit allComplete();
    }
}

//downloads icons and item stat files
//when both are done emits signal which triggers GUI creation
void RequestHandlerClass::completed() {
    if(caller == 0) {
        VectorHandler vh;
        QVector<QString> iconVector = vh.handleIcons();
        this->setInstances(vh.i/2, 1);
        QString url;
        for(int i = 0; i < iconVector.count(); i++) {
            i++;
            url = iconVector[i-1];
            this->download((i-1)/2, "http://eu.wowarmory.com/wow-icons/_images/51x51/" + url);
        }
    }
    else if(caller == 1) {
        VectorHandler vh;
        QVector<QString> vector = vh.handle();
        this->setInstances(vector.size()/2, 2);
        QString url;
        for(int i = 0; i < vector.count(); i++) {
            i++;
            url = vector[i-1];
            this->download((i-1)/2, "http://eu.wowarmory.com/item-tooltip.xml?i=" + url);
        }
    }
    else if(caller == 2) {
        emit thisFinished();
    }

}
